# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt

class SavingSummary(BaseModel):
    """
    A summary of the accrued interest for the saving account in the current period
    """
    apy: Optional[StrictInt] = Field(None, description="The annual percentage yield (APY) for this statement period, in basis points. For example, an APY of 5.5% will display as 550. ")
    interest_earned: Optional[StrictInt] = Field(None, description="The total interest earned by the depository account for this statement period in ISO 4217 minor currency units. For example, $1.50 USD of interest will be displayed as 150. ")
    interest_earned_previous_month: Optional[StrictInt] = Field(None, description="The total interest earned by the depository account in the previous statement period in ISO 4217 minor currency units. For example, $1.50 USD of interest will be displayed as 150. ")
    interest_earned_previous_year: Optional[StrictInt] = Field(None, description="The total interest earned by the depository account in the previous year in ISO 4217 minor currency units. For example, $100 USD of interest will be displayed as 10000. ")
    interest_earned_ytd: Optional[StrictInt] = Field(None, description="The total interest earned by the depository account for this year to date in ISO 4217 minor currency units. For example, $100 USD of interest will be displayed as 10000. ")
    __properties = ["apy", "interest_earned", "interest_earned_previous_month", "interest_earned_previous_year", "interest_earned_ytd"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SavingSummary:
        """Create an instance of SavingSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SavingSummary:
        """Create an instance of SavingSummary from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SavingSummary.parse_obj(obj)

        _obj = SavingSummary.parse_obj({
            "apy": obj.get("apy"),
            "interest_earned": obj.get("interest_earned"),
            "interest_earned_previous_month": obj.get("interest_earned_previous_month"),
            "interest_earned_previous_year": obj.get("interest_earned_previous_year"),
            "interest_earned_ytd": obj.get("interest_earned_ytd")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, conlist
from synctera_client_v1.models.transaction import Transaction

class SecurityAccountSummary(BaseModel):
    """
    A summary for the security account backing the credit account.
    """
    account_id: Optional[StrictStr] = Field(None, description="The unique identifier of the backing account.")
    account_number: Optional[StrictStr] = Field(None, description="Account number of the backing account.")
    account_type: Optional[StrictStr] = Field(None, description="The type of the account. It refers to the backing account. ")
    apy: Optional[StrictInt] = Field(None, description="The annual percentage yield (APY) for the security account for this statement period, in basis points. For example, an APY of 5.5% will display as 550. ")
    closing_balance: Optional[StrictInt] = Field(None, description="The security account balance at the end of the statement period, in ISO 4217 minor currency units. For example, $1,000 USD will be displayed as 100000.")
    disclosure: Optional[StrictStr] = None
    interest: Optional[StrictInt] = Field(None, description="The total interest earned by the security account for this statement period in ISO 4217 minor currency units. For example, $1.50 USD of interest will be displayed as 150. ")
    interest_previous_month: Optional[StrictInt] = Field(None, description="The total interest earned by the security account in the previous statement period in ISO 4217 minor currency units. For example, $1.50 USD of interest will be displayed as 150. ")
    interest_previous_year: Optional[StrictInt] = Field(None, description="The total interest earned by the security account in the previous year in ISO 4217 minor currency units. For example, $100 USD of interest will be displayed as 10000. ")
    interest_ytd: Optional[StrictInt] = Field(None, description="The total interest earned by the security account for this year to date in ISO 4217 minor currency units. For example, $100 USD of interest will be displayed as 10000. ")
    opening_balance: Optional[StrictInt] = Field(None, description="The security account balance at the start of the statement period, in ISO 4217 minor currency units. For example, $1,000 USD will be displayed as 100000.")
    transactions: Optional[conlist(Transaction)] = Field(None, description="This attribute is deprecated and will be removed. Use `GET /v0/statements/{statement_id}/transactions` instead.")
    __properties = ["account_id", "account_number", "account_type", "apy", "closing_balance", "disclosure", "interest", "interest_previous_month", "interest_previous_year", "interest_ytd", "opening_balance", "transactions"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SecurityAccountSummary:
        """Create an instance of SecurityAccountSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in transactions (list)
        _items = []
        if self.transactions:
            for _item in self.transactions:
                if _item:
                    _items.append(_item.to_dict())
            _dict['transactions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SecurityAccountSummary:
        """Create an instance of SecurityAccountSummary from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SecurityAccountSummary.parse_obj(obj)

        _obj = SecurityAccountSummary.parse_obj({
            "account_id": obj.get("account_id"),
            "account_number": obj.get("account_number"),
            "account_type": obj.get("account_type"),
            "apy": obj.get("apy"),
            "closing_balance": obj.get("closing_balance"),
            "disclosure": obj.get("disclosure"),
            "interest": obj.get("interest"),
            "interest_previous_month": obj.get("interest_previous_month"),
            "interest_previous_year": obj.get("interest_previous_year"),
            "interest_ytd": obj.get("interest_ytd"),
            "opening_balance": obj.get("opening_balance"),
            "transactions": [Transaction.from_dict(_item) for _item in obj.get("transactions")] if obj.get("transactions") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class InternalTransferTransactionSubtypes(str, Enum):
    """
    The set of valid INTERNAL_TRANSFER transaction subtypes
    """

    """
    allowed enum values
    """
    ACCOUNT_DECREASE_LIMIT = 'ACCOUNT_DECREASE_LIMIT'
    ACCOUNT_DECREASE_LIMIT_REVERSAL = 'ACCOUNT_DECREASE_LIMIT_REVERSAL'
    ACCOUNT_INCREASE_LIMIT = 'ACCOUNT_INCREASE_LIMIT'
    ACCOUNT_INCREASE_LIMIT_REVERSAL = 'ACCOUNT_INCREASE_LIMIT_REVERSAL'
    ACCOUNT_TO_ACCOUNT = 'ACCOUNT_TO_ACCOUNT'
    ACCOUNT_TO_ACCOUNT_REVERSAL = 'ACCOUNT_TO_ACCOUNT_REVERSAL'
    ACCOUNT_TO_ACCOUNT_SWEEP = 'ACCOUNT_TO_ACCOUNT_SWEEP'
    ACCOUNT_TO_ACCOUNT_SWEEP_REVERSAL = 'ACCOUNT_TO_ACCOUNT_SWEEP_REVERSAL'
    ACH_CREDIT_SWEEP = 'ACH_CREDIT_SWEEP'
    ACH_CREDIT_SWEEP_REVERSAL = 'ACH_CREDIT_SWEEP_REVERSAL'
    ACH_DEBIT_SWEEP = 'ACH_DEBIT_SWEEP'
    ACH_DEBIT_SWEEP_REVERSAL = 'ACH_DEBIT_SWEEP_REVERSAL'
    ACH_FLOAT_TRANSFER = 'ACH_FLOAT_TRANSFER'
    ACH_FLOAT_TRANSFER_REVERSAL = 'ACH_FLOAT_TRANSFER_REVERSAL'
    ACH_INCOMING_CREDIT_SWEEP = 'ACH_INCOMING_CREDIT_SWEEP'
    ACH_INCOMING_CREDIT_SWEEP_REVERSAL = 'ACH_INCOMING_CREDIT_SWEEP_REVERSAL'
    ACH_INCOMING_DEBIT_SWEEP = 'ACH_INCOMING_DEBIT_SWEEP'
    ACH_INCOMING_DEBIT_SWEEP_REVERSAL = 'ACH_INCOMING_DEBIT_SWEEP_REVERSAL'
    ACH_INCOMING_RETURN_CREDIT_SWEEP = 'ACH_INCOMING_RETURN_CREDIT_SWEEP'
    ACH_INCOMING_RETURN_CREDIT_SWEEP_REVERSAL = 'ACH_INCOMING_RETURN_CREDIT_SWEEP_REVERSAL'
    ACH_INCOMING_RETURN_DEBIT_SWEEP = 'ACH_INCOMING_RETURN_DEBIT_SWEEP'
    ACH_INCOMING_RETURN_DEBIT_SWEEP_REVERSAL = 'ACH_INCOMING_RETURN_DEBIT_SWEEP_REVERSAL'
    ACH_OUTGOING_CREDIT_SWEEP = 'ACH_OUTGOING_CREDIT_SWEEP'
    ACH_OUTGOING_CREDIT_SWEEP_REVERSAL = 'ACH_OUTGOING_CREDIT_SWEEP_REVERSAL'
    ACH_OUTGOING_DEBIT_SWEEP = 'ACH_OUTGOING_DEBIT_SWEEP'
    ACH_OUTGOING_DEBIT_SWEEP_REVERSAL = 'ACH_OUTGOING_DEBIT_SWEEP_REVERSAL'
    ACH_OUTGOING_RETURN_CREDIT_SWEEP = 'ACH_OUTGOING_RETURN_CREDIT_SWEEP'
    ACH_OUTGOING_RETURN_CREDIT_SWEEP_REVERSAL = 'ACH_OUTGOING_RETURN_CREDIT_SWEEP_REVERSAL'
    ACH_OUTGOING_RETURN_DEBIT_SWEEP = 'ACH_OUTGOING_RETURN_DEBIT_SWEEP'
    ACH_OUTGOING_RETURN_DEBIT_SWEEP_REVERSAL = 'ACH_OUTGOING_RETURN_DEBIT_SWEEP_REVERSAL'
    ACH_SWEEP = 'ACH_SWEEP'
    ACH_SWEEP_REVERSAL = 'ACH_SWEEP_REVERSAL'
    CASHBACK = 'CASHBACK'
    CASHBACK_REVERSAL = 'CASHBACK_REVERSAL'
    CASHBACK_SWEEP = 'CASHBACK_SWEEP'
    CASHBACK_SWEEP_REVERSAL = 'CASHBACK_SWEEP_REVERSAL'
    CREDIT_MEMO = 'CREDIT_MEMO'
    CREDIT_MEMO_REVERSAL = 'CREDIT_MEMO_REVERSAL'
    DOMESTIC_WIRE_INCOMING_RETURN_SWEEP = 'DOMESTIC_WIRE_INCOMING_RETURN_SWEEP'
    DOMESTIC_WIRE_INCOMING_RETURN_SWEEP_REVERSAL = 'DOMESTIC_WIRE_INCOMING_RETURN_SWEEP_REVERSAL'
    DOMESTIC_WIRE_INCOMING_SWEEP = 'DOMESTIC_WIRE_INCOMING_SWEEP'
    DOMESTIC_WIRE_INCOMING_SWEEP_REVERSAL = 'DOMESTIC_WIRE_INCOMING_SWEEP_REVERSAL'
    DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP = 'DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP'
    DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP_REVERSAL = 'DOMESTIC_WIRE_OUTGOING_RETURN_SWEEP_REVERSAL'
    DOMESTIC_WIRE_OUTGOING_SWEEP = 'DOMESTIC_WIRE_OUTGOING_SWEEP'
    DOMESTIC_WIRE_OUTGOING_SWEEP_REVERSAL = 'DOMESTIC_WIRE_OUTGOING_SWEEP_REVERSAL'
    EXCHANGE_RATE_DIFFERENCE_GAIN = 'EXCHANGE_RATE_DIFFERENCE_GAIN'
    EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL = 'EXCHANGE_RATE_DIFFERENCE_GAIN_REVERSAL'
    EXCHANGE_RATE_DIFFERENCE_LOSS = 'EXCHANGE_RATE_DIFFERENCE_LOSS'
    EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL = 'EXCHANGE_RATE_DIFFERENCE_LOSS_REVERSAL'
    FEE = 'FEE'
    FEE_REVERSAL = 'FEE_REVERSAL'
    FEE_SWEEP = 'FEE_SWEEP'
    FEE_SWEEP_REVERSAL = 'FEE_SWEEP_REVERSAL'
    FORCE_PAYMENT = 'FORCE_PAYMENT'
    FORCE_PAYMENT_REVERSAL = 'FORCE_PAYMENT_REVERSAL'
    INCOMING_WIRE = 'INCOMING_WIRE'
    INCOMING_WIRE_REVERSAL = 'INCOMING_WIRE_REVERSAL'
    INCOMING_WIRE_SWEEP = 'INCOMING_WIRE_SWEEP'
    INCOMING_WIRE_SWEEP_REVERSAL = 'INCOMING_WIRE_SWEEP_REVERSAL'
    INTEREST_CHARGED = 'INTEREST_CHARGED'
    INTEREST_CHARGED_REVERSAL = 'INTEREST_CHARGED_REVERSAL'
    INTEREST_CHARGED_SWEEP = 'INTEREST_CHARGED_SWEEP'
    INTEREST_CHARGED_SWEEP_REVERSAL = 'INTEREST_CHARGED_SWEEP_REVERSAL'
    INTEREST_PAYOUT = 'INTEREST_PAYOUT'
    INTEREST_PAYOUT_REVERSAL = 'INTEREST_PAYOUT_REVERSAL'
    INTEREST_PAYOUT_SWEEP = 'INTEREST_PAYOUT_SWEEP'
    INTEREST_PAYOUT_SWEEP_REVERSAL = 'INTEREST_PAYOUT_SWEEP_REVERSAL'
    INTERNATIONAL_WIRE_OUTGOING_SWEEP = 'INTERNATIONAL_WIRE_OUTGOING_SWEEP'
    INTERNATIONAL_WIRE_OUTGOING_SWEEP_REVERSAL = 'INTERNATIONAL_WIRE_OUTGOING_SWEEP_REVERSAL'
    INVOICE = 'INVOICE'
    INVOICE_REVERSAL = 'INVOICE_REVERSAL'
    JIT_FUND = 'JIT_FUND'
    JIT_FUND_REVERSAL = 'JIT_FUND_REVERSAL'
    LOAN_DISBURSEMENT = 'LOAN_DISBURSEMENT'
    LOAN_DISBURSEMENT_REVERSAL = 'LOAN_DISBURSEMENT_REVERSAL'
    LOAN_FUNDING = 'LOAN_FUNDING'
    LOAN_FUNDING_REVERSAL = 'LOAN_FUNDING_REVERSAL'
    LOC_USAGE = 'LOC_USAGE'
    LOC_USAGE_REVERSAL = 'LOC_USAGE_REVERSAL'
    MANUAL_ADJUSTMENT = 'MANUAL_ADJUSTMENT'
    MANUAL_ADJUSTMENT_REVERSAL = 'MANUAL_ADJUSTMENT_REVERSAL'
    MANUAL_ADJUSTMENT_SWEEP = 'MANUAL_ADJUSTMENT_SWEEP'
    MANUAL_ADJUSTMENT_SWEEP_REVERSAL = 'MANUAL_ADJUSTMENT_SWEEP_REVERSAL'
    MANUAL_CARD_SWEEP = 'MANUAL_CARD_SWEEP'
    MANUAL_CARD_SWEEP_REVERSAL = 'MANUAL_CARD_SWEEP_REVERSAL'
    MANUAL_CHECK_SWEEP = 'MANUAL_CHECK_SWEEP'
    MANUAL_CHECK_SWEEP_REVERSAL = 'MANUAL_CHECK_SWEEP_REVERSAL'
    MANUAL_WIRE_SWEEP = 'MANUAL_WIRE_SWEEP'
    MANUAL_WIRE_SWEEP_REVERSAL = 'MANUAL_WIRE_SWEEP_REVERSAL'
    MASTERCARD_GROSS_SWEEP = 'MASTERCARD_GROSS_SWEEP'
    MASTERCARD_GROSS_SWEEP_REVERSAL = 'MASTERCARD_GROSS_SWEEP_REVERSAL'
    MASTERCARD_INTERCHANGE_SWEEP = 'MASTERCARD_INTERCHANGE_SWEEP'
    MASTERCARD_INTERCHANGE_SWEEP_REVERSAL = 'MASTERCARD_INTERCHANGE_SWEEP_REVERSAL'
    MASTERCARD_NET_SWEEP = 'MASTERCARD_NET_SWEEP'
    MASTERCARD_NET_SWEEP_REVERSAL = 'MASTERCARD_NET_SWEEP_REVERSAL'
    MOBILE_DEPOSIT_RETURN_SWEEP = 'MOBILE_DEPOSIT_RETURN_SWEEP'
    MOBILE_DEPOSIT_RETURN_SWEEP_REVERSAL = 'MOBILE_DEPOSIT_RETURN_SWEEP_REVERSAL'
    MOBILE_DEPOSIT_SWEEP = 'MOBILE_DEPOSIT_SWEEP'
    MOBILE_DEPOSIT_SWEEP_REVERSAL = 'MOBILE_DEPOSIT_SWEEP_REVERSAL'
    NETWORK_ADJUSTMENT_SWEEP = 'NETWORK_ADJUSTMENT_SWEEP'
    NETWORK_ADJUSTMENT_SWEEP_REVERSAL = 'NETWORK_ADJUSTMENT_SWEEP_REVERSAL'
    NETWORK_CHARGEBACK_SWEEP = 'NETWORK_CHARGEBACK_SWEEP'
    NETWORK_CHARGEBACK_SWEEP_REVERSAL = 'NETWORK_CHARGEBACK_SWEEP_REVERSAL'
    OUTGOING_INTERNATIONAL_REMITTANCE = 'OUTGOING_INTERNATIONAL_REMITTANCE'
    OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL = 'OUTGOING_INTERNATIONAL_REMITTANCE_REVERSAL'
    PROGRAM_DECREASE = 'PROGRAM_DECREASE'
    PROGRAM_DECREASE_REVERSAL = 'PROGRAM_DECREASE_REVERSAL'
    PROGRAM_EXPANSION = 'PROGRAM_EXPANSION'
    PROGRAM_EXPANSION_REVERSAL = 'PROGRAM_EXPANSION_REVERSAL'
    PROMOTIONAL_CREDIT = 'PROMOTIONAL_CREDIT'
    PROMOTIONAL_CREDIT_REVERSAL = 'PROMOTIONAL_CREDIT_REVERSAL'
    PROMOTIONAL_CREDIT_SWEEP = 'PROMOTIONAL_CREDIT_SWEEP'
    PROMOTIONAL_CREDIT_SWEEP_REVERSAL = 'PROMOTIONAL_CREDIT_SWEEP_REVERSAL'
    PULSE_GROSS_SWEEP = 'PULSE_GROSS_SWEEP'
    PULSE_GROSS_SWEEP_REVERSAL = 'PULSE_GROSS_SWEEP_REVERSAL'
    PULSE_INTERCHANGE_SWEEP = 'PULSE_INTERCHANGE_SWEEP'
    PULSE_INTERCHANGE_SWEEP_REVERSAL = 'PULSE_INTERCHANGE_SWEEP_REVERSAL'
    REPAYMENT = 'REPAYMENT'
    REPAYMENT_REVERSAL = 'REPAYMENT_REVERSAL'
    SECURITY_ACCOUNT_PAYMENT = 'SECURITY_ACCOUNT_PAYMENT'
    SECURITY_ACCOUNT_PAYMENT_REVERSAL = 'SECURITY_ACCOUNT_PAYMENT_REVERSAL'
    SIGN_UP_BONUS = 'SIGN_UP_BONUS'
    SIGN_UP_BONUS_REVERSAL = 'SIGN_UP_BONUS_REVERSAL'
    SUBSCRIPTION_FEE = 'SUBSCRIPTION_FEE'
    SUBSCRIPTION_FEE_REVERSAL = 'SUBSCRIPTION_FEE_REVERSAL'
    TRANSFER_FEE = 'TRANSFER_FEE'
    TRANSFER_FEE_REVERSAL = 'TRANSFER_FEE_REVERSAL'
    TRANSFER_FEE_REVERSAL_REVERSAL = 'TRANSFER_FEE_REVERSAL_REVERSAL'

    @classmethod
    def from_json(cls, json_str: str) -> InternalTransferTransactionSubtypes:
        """Create an instance of InternalTransferTransactionSubtypes from a JSON string"""
        return InternalTransferTransactionSubtypes(json.loads(json_str))





# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import date
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class CreditSummary(BaseModel):
    """
    A summary of the accrued interest for the credit account in the current period
    """
    amount_past_due: Optional[StrictInt] = Field(None, description="Amount past due refers to any outstanding amount unpaid by the cutoff time on the  due date for this account in ISO 4217 minor currency units (e.g. $1000.00 is 100000).  ")
    apr: Optional[StrictInt] = Field(None, description="Basis points(BPS) of annual percentage rate of the credit account")
    balance_for_interest: Optional[StrictInt] = Field(None, description="Balance on which interest is computed during the time interval covered by the statement")
    credit_limit: Optional[StrictInt] = Field(None, description="The credit limit of the credit account in ISO 4217 minor currency units, not applicable for charge accounts")
    current_balance: Optional[StrictInt] = Field(None, description="The credit account balance outstanding on the ending of the time interval covered by the statement. This field is deprecated, use `statement.closing_balance` instead.")
    disclosure: Optional[StrictStr] = Field(None, description="A suggested regulatory disclosure to display on the statement.")
    fees: Optional[StrictInt] = Field(None, description="The total fees charged on the credit account in ISO 4217 minor currency units during the time interval covered by the statement")
    fees_ytd: Optional[StrictInt] = Field(None, description="The total fees charged on the credit account in ISO 4217 minor currency units for the year to date")
    interest: Optional[StrictInt] = Field(None, description="The total interest charged on the credit account in ISO 4217 minor currency units during the time interval covered by the statement")
    interest_ytd: Optional[StrictInt] = Field(None, description="The total interest charged on the credit account in ISO 4217 minor currency units for the year to date")
    is_past_due: Optional[StrictBool] = Field(None, description="Whether or not the credit account is past due on payment.")
    last_payment_date: Optional[date] = Field(None, description="The date of the last payment received")
    minimum_payment_due: Optional[StrictInt] = Field(None, description="The minimum payment amount due by the payment due date in ISO 4217 minor currency units.")
    payment_due_date: Optional[date] = Field(None, description="The date the next payment is due")
    payments_received: Optional[StrictInt] = Field(None, description="The sum of all payments received in ISO 4217 minor currency units.")
    previous_balance: Optional[StrictInt] = Field(None, description="The previous balance of the credit account in ISO 4217 minor currency units. This field is deprecated, use `statement.opening_balance` instead.")
    __properties = ["amount_past_due", "apr", "balance_for_interest", "credit_limit", "current_balance", "disclosure", "fees", "fees_ytd", "interest", "interest_ytd", "is_past_due", "last_payment_date", "minimum_payment_due", "payment_due_date", "payments_received", "previous_balance"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreditSummary:
        """Create an instance of CreditSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreditSummary:
        """Create an instance of CreditSummary from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CreditSummary.parse_obj(obj)

        _obj = CreditSummary.parse_obj({
            "amount_past_due": obj.get("amount_past_due"),
            "apr": obj.get("apr"),
            "balance_for_interest": obj.get("balance_for_interest"),
            "credit_limit": obj.get("credit_limit"),
            "current_balance": obj.get("current_balance"),
            "disclosure": obj.get("disclosure"),
            "fees": obj.get("fees"),
            "fees_ytd": obj.get("fees_ytd"),
            "interest": obj.get("interest"),
            "interest_ytd": obj.get("interest_ytd"),
            "is_past_due": obj.get("is_past_due"),
            "last_payment_date": obj.get("last_payment_date"),
            "minimum_payment_due": obj.get("minimum_payment_due"),
            "payment_due_date": obj.get("payment_due_date"),
            "payments_received": obj.get("payments_received"),
            "previous_balance": obj.get("previous_balance")
        })
        return _obj




# coding: utf-8

"""
    Synctera API

    <h2>Let's build something great.</h2><p>Welcome to the official reference documentation for Synctera APIs. Our APIs are the best way to automate your company's banking needs and are designed to be easy to understand and implement.</p><p>We're continuously growing this library and what you see here is just the start, but if you need something specific or have a question, <a class='text-blue-600' href='https://synctera.com/contact' target='_blank' rel='noreferrer'>contact us</a>.</p>  # noqa: E501

    The version of the OpenAPI document: 1.41.3
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictStr

from synctera_client_v1.models.simulate_card_fulfillment import SimulateCardFulfillment

from synctera_client_v1.api_client import ApiClient
from synctera_client_v1.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class CardWebhookSimulationsBetaApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def simulate_card_fulfillment_event(self, card_id : StrictStr, simulate_card_fulfillment : Annotated[SimulateCardFulfillment, Field(..., description="Desired simulated fulfillment status change value")], **kwargs) -> SimulateCardFulfillment:  # noqa: E501
        """Simulate Card Fulfillment Event  # noqa: E501

        > 🚧 Beta > This is a Beta endpoint. Feedback from the community is welcome. We may make breaking changes to this endpoint.  This endpoint is for testing environment only to trigger a simulated change in card fulfillment status event   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.simulate_card_fulfillment_event(card_id, simulate_card_fulfillment, async_req=True)
        >>> result = thread.get()

        :param card_id: (required)
        :type card_id: str
        :param simulate_card_fulfillment: Desired simulated fulfillment status change value (required)
        :type simulate_card_fulfillment: SimulateCardFulfillment
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SimulateCardFulfillment
        """
        kwargs['_return_http_data_only'] = True
        return self.simulate_card_fulfillment_event_with_http_info(card_id, simulate_card_fulfillment, **kwargs)  # noqa: E501

    @validate_arguments
    def simulate_card_fulfillment_event_with_http_info(self, card_id : StrictStr, simulate_card_fulfillment : Annotated[SimulateCardFulfillment, Field(..., description="Desired simulated fulfillment status change value")], **kwargs):  # noqa: E501
        """Simulate Card Fulfillment Event  # noqa: E501

        > 🚧 Beta > This is a Beta endpoint. Feedback from the community is welcome. We may make breaking changes to this endpoint.  This endpoint is for testing environment only to trigger a simulated change in card fulfillment status event   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.simulate_card_fulfillment_event_with_http_info(card_id, simulate_card_fulfillment, async_req=True)
        >>> result = thread.get()

        :param card_id: (required)
        :type card_id: str
        :param simulate_card_fulfillment: Desired simulated fulfillment status change value (required)
        :type simulate_card_fulfillment: SimulateCardFulfillment
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SimulateCardFulfillment, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'card_id',
            'simulate_card_fulfillment'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method simulate_card_fulfillment_event" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['card_id']:
            _path_params['card_id'] = _params['card_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['simulate_card_fulfillment']:
            _body_params = _params['simulate_card_fulfillment']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "SimulateCardFulfillment",
            '400': "Error",
            '401': "Error",
            '403': "Error",
            '422': "Error",
            '500': "Error",
        }

        return self.api_client.call_api(
            '/cards/{card_id}/webhook_simulations/fulfillment', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
